---
title: base
sidebarTitle: base
---

# `catalax.model.base`

## Classes

### `CatalaxBase` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/base.py#L5" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>
